@@ -1,17 +1,21 @@
 //! rsw cli
 
 mod build;
+mod clean;
 mod cli;
 mod create;
 mod error;
 mod info;
 mod init;
+mod link;
 mod watch;
 
 pub use self::build::Build;
+pub use self::clean::Clean;
 pub use self::cli::Cli;
 pub use self::create::Create;
 pub use self::error::RswErr;
 pub use self::info::RswInfo;
 pub use self::init::Init;
+pub use self::link::Link;
 pub use self::watch::Watch;
